class DomManager {
    constructor() {
        this.fullName = ".full-name";
        this.fullNameSN = ".member-name";
        this.profilePic = ".profile-picture img";
        this.profilePicSN = "img.member-image";
        this.currentPosition = ".current-position";
        this.currentPositionSN = ".position-title";
        this.position = "li.position";
        this.currentCompany = "h5 a";
        this.currentTitle = "h4 a";
        this.companyName = ".company-name";
        this.email = "#email li";
        this.profileUrl = ".view-public-profile";
        this.htmlProfileUrl = ".public-profile-url";
        this.profileUrlSN = ".more-info-tray a";
        this.profile = "#profile";
        this.locality = ".locality";
        this.location = ".location";
        this.navProfilePic = ".nav-profile-photo";
        this.navProfilePicSN = ".profile-photo";
        this.profileOverview = ".profile-overiview";
        this.endorsements = "#endorsements";
        this.backgroundExperience = "#background-experience";
        this.experience = "#experience";
        this.recommendations = "#recommendations";
        this.editFieldIcon = ".edit-field-icon";
        this.orange = "#e67e22";
        this.red = "#e74c3c";
        this.green = "#27ae60";
    }
    getName() {
        if (LiVersion.isSalesNav()) {
            if (LiVersion.isNewLSN()) {
                return $(".profile-topcard-person-entity__content").find("span").first().text().trim();
            }
            else {
                return $(this.fullNameSN).first().text().trim();
            }
        }
        else if (LiVersion.isNewLIUI())
            return $(".pv-top-card-section__name").text().trim();
        else
            return $(this.fullName).first().text().trim();
    }
    clean_name(b) {
        if (b) {
            const list = ["Jr", "Dr", "Mr", "Mrs", "Mme", "Sr", "MBA", "CPA", "PhD", "MD", "MHA", "CGA", "ACCA", "PMP", "MSc", "MBA", "Ph.D", "Eng", "CPIM", "PMP", "CSCP", "PHR"];
            b = b.replace(/^\s+|\s+$/g, "");
            b = b.replace(/\s+/g, " ");
            b = b.split(/,|;|\.|\_|\||\(/gi)[0];
            for (const x in list) {
                if (b.indexOf(list[x]) > -1) {
                    b = b.replace(list[x], "");
                }
            }
            return b.trim();
        }
        else {
            return;
        }
    }
    parsePage(html) {
        var companyIdSN;
        var emailSN;
        const obj = {};
        // SN
        if (LiVersion.isSalesNav()) {
            if (LiVersion.isNewLSN()) {
                // fullName
                obj.fullName = $(".profile-topcard-person-entity__content").find("span").first().text().trim();
                // Company URL
                companyIdSN = $(".profile-position__secondary-title").first().find("a").attr("href") || "";
                companyIdSN = companyIdSN.split("/");
                companyIdSN = companyIdSN[companyIdSN.length - 1];
                obj.companyUrl = consts.linkedinCompanyPath + companyIdSN;
            }
            else {
                // Email
                $(this.profileUrlSN).each(function () {
                    const url = $(this).attr("href");
                    if (url.indexOf("mailto") > -1) {
                        emailSN = url.split("mailto:")[1];
                        return false;
                    }
                });
                if (emailSN)
                    obj.email = emailSN;
                // Company URL & name
                $(this.position).first().find("a").each(function () {
                    const href = $(this).attr("href");
                    if (href && href.indexOf(consts.companyIdParamSN) > -1) {
                        companyIdSN = href.split(consts.companyIdParamSN + "=")[1];
                    }
                });
                if (companyIdSN) {
                    obj.companyUrl = consts.linkedinCompanyPath + companyIdSN;
                }
                obj.fullName = $(this.fullNameSN).text().trim();
            }
        }
        else if (LiVersion.isNewLIUI()) {
            function proceed() {
                // Full name
                try {
                    obj.fullName = $(".pv-top-card-section__name").text().trim();
                }
                catch (e) {
                    console.error("Error while parsing fullname");
                }
                // Company url
                try {
                    obj.companyUrl = $($('a[data-control-name="background_details_company"')[0]).attr("href");
                }
                catch (e) {
                    console.error("Error while parsing company url");
                }
            }
            proceed();
        }
        else {
            if ($(this.email).length > 0 && $(this.email).text() !== "") {
                obj.email = $(this.email).text().trim();
            }
            // Company URL & name
            obj.companyUrl = $(this.currentPosition).find(this.currentCompany).attr("href");
            obj.fullName = $(this.fullName).text().trim();
        }
        return obj;
    }
    getProfileId(done) {
        const htmlUrl = $(this.htmlProfileUrl).html(), href = $(this.profileUrl).attr("href");
        if (LiVersion.isSalesNav()) {
            if (LiVersion.isNewLSN()) {
                return done(window.location.pathname.replace("/", ""));
            }
            else {
                for (var i = 0; i < $(this.profileUrlSN).length; i++) {
                    if ($($(this.profileUrlSN)[i]).attr("href") && $($(this.profileUrlSN)[i]).attr("href").indexOf("/pub/") > -1) {
                        done("pub/" + $($(this.profileUrlSN)[i]).attr("href").split("/pub/")[1]);
                        return false;
                    }
                }
                return done();
            }
        }
        else if (LiVersion.isNewLIUI()) {
            try {
                done("in/" + window.location.href.split("/in/")[1].split("&")[0]);
            }
            catch (e) {
                console.error(e);
                done();
            }
        }
        else {
            if (href) {
                done("in/" + href.split("/in/")[1]);
            }
            else if (htmlUrl) {
                done("in/" + htmlUrl.split("/in/")[1]);
            }
            else {
                done("");
            }
            return false;
        }
    }
    ownProfileNLI() {
        return $(".profile-photo-edit__preview").length > 0;
    }
    getEmailNLI(callback) {
        document.getElementsByClassName("pv-top-card-v2-section__link--contact-info")[0].click();
        const interval = setInterval(function () {
            const modal = $('artdeco-modal[aria-labelledby="pv-contact-info"]');
            var links, email;
            if (modal.length > 0) {
                links = modal.find(".pv-contact-info__contact-link");
                links.each(function () {
                    if ($(this).attr("href") && $(this).attr("href").indexOf("mailto") > -1) {
                        email = $(this).attr("href").replace("mailto:", "");
                        clearInterval(interval);
                        modal.find('li-icon[type="cancel-icon"]').click();
                    }
                });
                callback(email);
            }
        }, 100);
    }
    getImgUrlNLI() {
        return ($(".pv-top-card-section__photo").css("background-image") || $(".profile-photo-edit__preview").attr("src") || "").replace('url("', "").replace('")', "");
    }
    getImgUrlSN() {
        return $(".profile-topcard-person-entity__image img").attr("src");
    }
    getImgUrl() {
        var img, mediaUrl;
        img = LiVersion.isSalesNav() ? $(this.profilePicSN) : LiVersion.isNewLIUI() ? $(".pv-top-card-section__image") : $(this.profilePic);
        mediaUrl = consts.linkedinImgUrl;
        if (img && img.attr("src") && img.attr("src") !== "") {
            return img.attr("src").replace(mediaUrl, "");
        }
        return;
    }
    getTitle() {
        if (LiVersion.isSalesNav()) {
            if (LiVersion.isNewLSN()) {
                return $(".profile-position__title").first().text().trim();
            }
            else {
                return $(this.currentPositionSN).first().html() ? $(this.currentPositionSN).first().html().trim() : "";
            }
        }
        else if (LiVersion.isNewLIUI()) {
            try {
                const fpos = $($(".pv-entity__position-group-pager")[0]);
                if (fpos.find(".pv-entity__summary-info-v2").length > 0) {
                    return $(fpos.find(".pv-entity__summary-info-v2 h3 span")[1]).text().trim();
                }
                else {
                    return $(".pv-position-entity .pv-entity__summary-info h3").first().text().trim();
                }
            }
            catch (e) {
                console.error("Error parsing title");
                return "";
            }
        }
        else {
            return $(this.currentPosition).find(this.currentTitle) ? $($(this.currentPosition).find(this.currentTitle)[0]).text().trim() : "";
        }
    }
    getCompany() {
        var company;
        if (LiVersion.isSalesNav()) {
            if (LiVersion.isNewLSN()) {
                return $(".profile-position__secondary-title").first().find("span").last().text().trim();
            }
            else {
                company = $(this.companyName).first();
                if (company)
                    return company.text() || "";
            }
        }
        else if (LiVersion.isNewLIUI()) {
            try {
                const fpos = $($(".pv-entity__position-group-pager")[0]);
                if (fpos.find(".pv-entity__summary-info-v2").length > 0) {
                    return $(fpos.find(".pv-entity__company-summary-info h3 span")[1]).text().trim();
                }
                else {
                    return $($(".pv-position-entity .pv-entity__summary-info h4").first().find("span")[1]).text().trim();
                }
            }
            catch (e) {
                console.error("Error parsing company");
                return "";
            }
        }
        else
            return $($(this.currentPosition).find(this.currentCompany)[1]).text().trim();
    }
    getLocation() {
        if (LiVersion.isSalesNav()) {
            if (LiVersion.isNewLSN()) {
                return $(".profile-topcard__location-data").text().trim();
            }
            else {
                return $(".info-container " + location) ? $(".info-container " + location).html() : "";
            }
        }
        else if (LiVersion.isNewLIUI()) {
            try {
                return $("h3.pv-top-card-section__location").first().text().trim();
            }
            catch (e) {
                console.error("Error parsing location");
                return "";
            }
        }
        else {
            return $(this.locality) && $(this.locality).first() ? $(this.locality).first().text() : "";
        }
    }
    simuScroll() {
        $("html, body").animate({ scrollTop: $(document).height() });
        $("html, body").animate({ scrollTop: 0 });
    }
}
class LiVersion {
    static isSalesNav() {
        const salesKW = "sales";
        return window.location.pathname.indexOf(salesKW) > -1;
    }
    static isNewLSN() {
        return $(".profile-topcard-actions").length > 0;
    }
    static isNewLSNBeta() {
        return $(".search-nav__profile-context ").length > 0;
    }
    static isNewLIUI() {
        return !!$("nav#extended-nav").length;
    }
}
var consts = {
    linkedinCompanyPath: "/company/",
    companyIdParamSN: "companyId",
    linkedinImgUrl: "https://media.licdn.com/"
};
//# sourceMappingURL=dom.js.map